@@ -2,8 +2,8 @@ package Leyland::Localizer;
 
 # ABSTRACT: Wrapper for the Locale::Wolowitz localization system for Leyland apps
 
-use Moose;
-use namespace::autoclean;
+use Moo;
+use namespace::clean;
 use Locale::Wolowitz;
 
 =head1 NAME
@@ -12,22 +12,24 @@ Leyland::Localizer - Wrapper for the Locale::Wolowitz localization system for Le
 
 =head1 VERSION
 
-version 0.001007
+version 1.000000
 
 =head1 SYNOPSIS
 
-	# in app.psgi
-	my $config = {
-		...
-		locales => '/path/to/myapp/locales',
-		...
-	};
+	# in your app's main package
+	sub setup {
+		return {
+			...
+			locales => '/path/to/myapp/locales',
+			...
+		};
+	}
 
 	# in your controllers
 	$c->set_lang('es'); # use Spanish when responding, possibly because that's what the client wants
 	$c->loc('Hello %1', $c->params->{name});
 
-	# in your views (assuming you're using L<Tenjin>):
+	# in your views (assuming you're using L<Tenjin|Leyland::View::Tenjin>):
 	<h1>[== $c->loc('Hello %1', $c->params->{name}) =]</h1>
 
 =head1 DESCRIPTION
@@ -65,13 +67,18 @@ L<Locale::Wolowitz> for more information.
 
 =cut
 
-has 'path' => (is => 'ro', isa => 'Str', required => 1);
+has 'path' => (
+	is => 'ro',
+	isa => sub { die "path must be a scalar" if ref $_[0] },
+	required => 1
+);
 
-has 'w' => (is => 'ro', isa => 'Locale::Wolowitz', writer => '_set_w');
-
-sub loc {
-	shift->w->loc(@_);
-}
+has 'w' => (
+	is => 'ro',
+	isa => sub { die "w must be a Locale::Wolowitz object" unless ref $_[0] && ref $_[0] eq 'Locale::Wolowitz' },
+	writer => '_set_w',
+	handles => ['loc']
+);
 
 =head1 INTERNAL METHODS
 
@@ -79,10 +86,6 @@ The following methods are only to be used internally.
 
 =head2 BUILD()
 
-Automatically called by L<Moose> after initializing an instance of this class,
-this method creates a new L<Locale::Wolowitz> object and saves it as the
-"w" attribute.
-
 =cut
 
 sub BUILD {
@@ -129,7 +132,7 @@ L<http://search.cpan.org/dist/Leyland/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2011 Ido Perlmuter.
+Copyright 2010-2014 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -139,4 +142,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+1;
