@@ -2,8 +2,8 @@ package Leyland::View::Tenjin;
 
 # ABSTRACT: Tenjin view class for Leyland
 
-use Moose;
-use namespace::autoclean;
+use Moo;
+use namespace::clean;
 use Tenjin 0.070001;
 
 =head1 NAME
@@ -12,16 +12,19 @@ Leyland::View::Tenjin - Tenjin view class for Leyland
 
 =head1 VERSION
 
-version 0.001007
+version 1.000000
 
 =head1 SYNOPSIS
 
-	# in app.psgi:
-	my $config = {
-		...
-		views => ['Tenjin'],
-		...
-	};
+	# in your app's class
+	sub setup {
+		return {
+			...
+			views => ['Tenjin'], # this is the default
+			view_dir => 'views', # this is also the default
+			...
+		};
+	}
 
 =head1 DESCRIPTION
 
@@ -42,7 +45,11 @@ The L<Tenjin> object used.
 
 with 'Leyland::View';
 
-has 'engine' => (is => 'ro', isa => 'Tenjin', builder => '_init_engine');
+has 'engine' => (
+	is => 'ro',
+	isa => sub { die "engine must be a Tenjin object" unless ref $_[0] && ref $_[0] eq 'Tenjin' },
+	writer => '_set_engine'
+);
 
 =head1 OBJECT METHODS
 
@@ -62,14 +69,20 @@ sub render {
 
 =head1 INTERNAL METHODS
 
-The following methods are only to be used internally.
-
-=head2 _init_engine()
+=head2 BUILD
 
 =cut
 
-sub _init_engine {
-	return Tenjin->new({ path => ['views'], postfix => '.html', layout => 'layouts/main.html' });
+sub BUILD {
+	my $self = shift;
+
+	$self->_set_engine(
+		Tenjin->new({
+			path => [$self->view_dir],
+			postfix => '.html',
+			layout => 'layouts/main.html'
+		})
+	);
 }
 
 =head1 AUTHOR
@@ -112,7 +125,7 @@ L<http://search.cpan.org/dist/Leyland/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2011 Ido Perlmuter.
+Copyright 2010-2014 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -122,4 +135,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
+1;
